.. _steering-optimal:

Optimal control for vehicle steeering (lane change)
---------------------------------------------------

Code
....
.. literalinclude:: steering-optimal.py
   :language: python
   :linenos:


Notes
.....
